@@ -1,5 +1,5 @@
-# regression test for SAX 2.0
-# $Id: test_sax.py,v 1.16 2001/01/18 02:22:22 tim_one Exp $
+# regression test for SAX 2.0            -*- coding: iso-8859-1 -*-
+# $Id: test_sax.py,v 1.24.16.3 2004/07/18 18:36:18 loewis Exp $
 
 from xml.sax import make_parser, ContentHandler, \
                     SAXException, SAXReaderNotAvailable, SAXParseException
@@ -8,26 +8,28 @@ try:
 except SAXReaderNotAvailable:
     # don't try to test this module if we cannot create a parser
     raise ImportError("no XML parsers available")
-from xml.sax.saxutils import XMLGenerator, escape, XMLFilterBase
+from xml.sax.saxutils import XMLGenerator, escape, unescape, quoteattr, \
+                             XMLFilterBase
 from xml.sax.expatreader import create_parser
 from xml.sax.xmlreader import InputSource, AttributesImpl, AttributesNSImpl
 from cStringIO import StringIO
-from test_support import verify, verbose, TestFailed, findfile
+from test.test_support import verify, verbose, TestFailed, findfile
+import os
 
 # ===== Utilities
 
 tests = 0
-fails = 0
+failures = []
 
 def confirm(outcome, name):
-    global tests, fails
+    global tests
 
     tests = tests + 1
     if outcome:
-        print "Passed", name
+        if verbose:
+            print "Passed", name
     else:
-        print "Failed", name
-        fails = fails + 1
+        failures.append(name)
 
 def test_make_parser2():
     try:
@@ -69,6 +71,39 @@ def test_escape_all():
 def test_escape_extra():
     return escape("Hei p deg", {"" : "&aring;"}) == "Hei p&aring; deg"
 
+# ===== unescape
+
+def test_unescape_basic():
+    return unescape("Donald Duck &amp; Co") == "Donald Duck & Co"
+
+def test_unescape_all():
+    return unescape("&lt;Donald Duck &amp; Co&gt;") == "<Donald Duck & Co>"
+
+def test_unescape_extra():
+    return unescape("Hei p deg", {"" : "&aring;"}) == "Hei p&aring; deg"
+
+def test_unescape_amp_extra():
+    return unescape("&amp;foo;", {"&foo;": "splat"}) == "&foo;"
+
+# ===== quoteattr
+
+def test_quoteattr_basic():
+    return quoteattr("Donald Duck & Co") == '"Donald Duck &amp; Co"'
+
+def test_single_quoteattr():
+    return (quoteattr('Includes "double" quotes')
+            == '\'Includes "double" quotes\'')
+
+def test_double_quoteattr():
+    return (quoteattr("Includes 'single' quotes")
+            == "\"Includes 'single' quotes\"")
+
+def test_single_double_quoteattr():
+    return (quoteattr("Includes 'single' and \"double\" quotes")
+            == "\"Includes 'single' and &quot;double&quot; quotes\"")
+
+# ===== make_parser
+
 def test_make_parser():
     try:
         # Creating a parser should succeed - it should fall back
@@ -130,6 +165,22 @@ def test_xmlgen_content_escape():
 
     return result.getvalue() == start + "<doc>&lt;huhei&amp;</doc>"
 
+def test_xmlgen_attr_escape():
+    result = StringIO()
+    gen = XMLGenerator(result)
+
+    gen.startDocument()
+    gen.startElement("doc", {"a": '"'})
+    gen.startElement("e", {"a": "'"})
+    gen.endElement("e")
+    gen.startElement("e", {"a": "'\""})
+    gen.endElement("e")
+    gen.endElement("doc")
+    gen.endDocument()
+
+    return result.getvalue() == start \
+           + "<doc a='\"'><e a=\"'\"></e><e a=\"'&quot;\"></e></doc>"
+
 def test_xmlgen_ignorable():
     result = StringIO()
     gen = XMLGenerator(result)
@@ -193,7 +244,7 @@ def test_expat_file():
     xmlgen = XMLGenerator(result)
 
     parser.setContentHandler(xmlgen)
-    parser.parse(open(findfile("test.xml")))
+    parser.parse(open(findfile("test"+os.extsep+"xml")))
 
     return result.getvalue() == xml_test_out
 
@@ -301,7 +352,7 @@ def test_expat_nsattrs_wattr():
 
     return attrs.getLength() == 1 and \
            attrs.getNames() == [(ns_uri, "attr")] and \
-           attrs.getQNames() == [] and \
+           (attrs.getQNames() == [] or attrs.getQNames() == ["ns:attr"]) and \
            len(attrs) == 1 and \
            attrs.has_key((ns_uri, "attr")) and \
            attrs.keys() == [(ns_uri, "attr")] and \
@@ -314,7 +365,7 @@ def test_expat_nsattrs_wattr():
 
 # ===== InputSource support
 
-xml_test_out = open(findfile("test.xml.out")).read()
+xml_test_out = open(findfile("test"+os.extsep+"xml"+os.extsep+"out")).read()
 
 def test_expat_inpsource_filename():
     parser = create_parser()
@@ -322,7 +373,7 @@ def test_expat_inpsource_filename():
     xmlgen = XMLGenerator(result)
 
     parser.setContentHandler(xmlgen)
-    parser.parse(findfile("test.xml"))
+    parser.parse(findfile("test"+os.extsep+"xml"))
 
     return result.getvalue() == xml_test_out
 
@@ -332,7 +383,7 @@ def test_expat_inpsource_sysid():
     xmlgen = XMLGenerator(result)
 
     parser.setContentHandler(xmlgen)
-    parser.parse(InputSource(findfile("test.xml")))
+    parser.parse(InputSource(findfile("test"+os.extsep+"xml")))
 
     return result.getvalue() == xml_test_out
 
@@ -343,7 +394,7 @@ def test_expat_inpsource_stream():
 
     parser.setContentHandler(xmlgen)
     inpsrc = InputSource()
-    inpsrc.setByteStream(open(findfile("test.xml")))
+    inpsrc.setByteStream(open(findfile("test"+os.extsep+"xml")))
     parser.parse(inpsrc)
 
     return result.getvalue() == xml_test_out
@@ -590,9 +641,9 @@ def make_test_output():
     xmlgen = XMLGenerator(result)
 
     parser.setContentHandler(xmlgen)
-    parser.parse(findfile("test.xml"))
+    parser.parse(findfile("test"+os.extsep+"xml"))
 
-    outf = open(findfile("test.xml.out"), "w")
+    outf = open(findfile("test"+os.extsep+"xml"+os.extsep+"out"), "w")
     outf.write(result.getvalue())
     outf.close()
 
@@ -602,6 +653,8 @@ for (name, value) in items:
     if name[ : 5] == "test_":
         confirm(value(), name)
 
-print "%d tests, %d failures" % (tests, fails)
-if fails != 0:
-    raise TestFailed, "%d of %d tests failed" % (fails, tests)
+if verbose:
+    print "%d tests, %d failures" % (tests, len(failures))
+if failures:
+    raise TestFailed("%d of %d tests failed: %s"
+                     % (len(failures), tests, ", ".join(failures)))
